@@ -1,25 +1,26 @@
 # -*- coding: utf-8 -*-
 
-# Import Python libs
 from __future__ import absolute_import
 
-# Import Salt Testing libs
+import pytest
+import salt.utils.platform
 from tests.support.case import ModuleCase
+from tests.support.helpers import slowTest
 from tests.support.unit import skipIf
 
-# Import Salt libs
-import salt.utils.platform
 
-
-@skipIf(not salt.utils.platform.is_windows(), 'windows tests only')
+@skipIf(not salt.utils.platform.is_windows(), "windows tests only")
+@pytest.mark.windows_whitelisted
 class AutoRunsModuleTest(ModuleCase):
-    '''
+    """
     Test the autoruns module
-    '''
+    """
+
+    @slowTest
     def test_win_autoruns_list(self):
-        '''
+        """
         test win_autoruns.list module
-        '''
-        ret = self.run_function('autoruns.list')
-        self.assertIn('HKLM', str(ret))
+        """
+        ret = self.run_function("autoruns.list")
+        self.assertIn("HKLM", str(ret))
         self.assertTrue(isinstance(ret, dict))
